
/* SWIG version information */

#ifndef SWIG_VERSION
#define SWIG_VERSION "1.3.6u-20010810-1535"
#endif

#ifndef SWIG_SPIN
#define SWIG_SPIN "6"
#endif
